**** This do file produces the analysis for the paper Manaresi Pierri (2022) JMBC "The Asymmetric Effect of Credit Supply on Firm-Level Productivity Growth"

*** To match a Table in the paper with a Table produced in the do file, please follow instruction 
*** For instance, the right panel of Table 1 is ${homecd}tables/des_firms_manu_4, while the left panel is ${homecd}tables/des_firms_all_4 


clear all
set more off
cap log close

local c_date=c(current_date)
local date_string = subinstr("`c_date'", " ", "_", .)

** Dasets inputs
* MAIN, dataset_postgmm`t', dataset_postgmm_rev`t' shock_1997-2013_win_Aug2015.dta
* "/CREDIT SUPPLY SHIFTERS/Bank_Firm_Shocks.dta"



** per osiride 2
global homecd "/home/group/main/creprod/"
 
log using "${homecd}log_file/analysis_cebi_`date_string'.log", replace

cap mkdir "${homecd}tables/may2022/"

global tables "${homecd}tables/jan2022/"
global tables_exit "${homecd}tables/exit/"
global tables_kreturn "${homecd}tables/kreturn/"
global tables_OPdecomp "${homecd}tables/OPdecomp/"
global tables_heter "${homecd}tables/heter/"
 

global graphs "${homecd}graphs/presub/"

global foranalysis "${homecd}dta/foranalysis.dta"
global dataset_secteffect "${homecd}dta/secteffect.dta"
global invind "${homecd}dta/indann_completo.dta"
global year_dta "${homecd}dta/yearlydata_july2017.dta"
global year_dta_manu "${homecd}dta/yearlydata_manu_july2017.dta"
global dataset_costshare "${homecd}dta/dataset_costshare.dta"
global dataset_mainbank "${homecd}dta/mainbank_id.csv"
global dataset_RZ "${homecd}dta/RZ.dta"
global dataset_split "${homecd}dta/shock_split_1998-2013.dta"
global patent_sector "${homecd}dta/patent_sector.dta"
global wms_npierri "/home/group/main/creprod/dta/finaldta/wms_npierri.dta"



*********** Specifications to run - YES the ones that are in the main body of the paper ***********
global robustness "Yes"
global descriptives "Yes"
global year_ldta "Yes"
global main_specification "Yes"
global itbk "Yes"
global inout_specification "Yes"
 global productivity_enhancing "Yes"
  
**I have only foranalysis_june2017

global foranalysis "${homecd}dta/foranalysis_june2017.dta"

global year_dta "${homecd}dta/yearlydata.dta"


global raw  cred va y k l   n_dip    matserv 
local kreturns   mrkva_cd   mrky_cd  mrkva_tl mrky_tl 
local log_kreturns   log_mrkva_cd   log_mrky_cd  log_mrkva_tl log_mrky_tl 
global controls cf_r  liq_r leverage va_r  book_value_k kbook_sq kbook_cb 

** define productivity variables 

global N_prodvar 4
global prodvar_1 prodva_cd
global prodvar_2 prodva_tl
global prodvar_3 prodrev_cd
global prodvar_4 prodrev_tl

local prods_types  EEXIT NE4dgs lev model
local cost_share res_shareva res_shareva_125 res_sharerev_ps res_sharerev  res_sharerev_ps_125  res_shareva_ttb res_shareva_125_ttb 



set seed 1994 
* my sis birth year

set tracedepth 1 
set trace off

import delimited $dataset_mainbank
rename codfisc fisc
g bla = year+1
drop year
rename bla year
tempfile mainbank_temp
save `mainbank_temp'

if "${hetereogeneity}"=="Yes" {
use $dataset_RZ, clear
rename ss sector
tempfile RZ_temp
save `RZ_temp'
}

use $invind, clear

destring codf, gen(fisc) force
tsset v2 annoril
replace fisc=L.fisc if L.fisc!=. & fisc==.

forvalues i=1/14 {
	replace fisc=F.fisc if F.fisc!=. & fisc==.
}

rename annoril year
duplicates drop fisc year, force


tempfile inv_temp
save `inv_temp'





use ${foranalysis}, clear

duplicates drop COD_CEN year, force

g const = 1 



if "${robustness}"=="Yes"  {

merge 1:1 COD_CEN year using $dataset_split , gen(m_split)
drop if m_split==2

winsor2 dlshock_ACCORDATO_tot_eoy_split, cuts(1 99) replace
rename dlshock_ACCORDATO_tot_eoy_split shifter_split


merge 1:1 fisc year using $dataset_costshare, gen(m_cs)
drop if  m_cs==2
bysort fisc: egen max_checkshacceoy = max(checkshACCORDATO_tot_eoy)

}




if "${itbk}"=="Yes" {
merge m:1 fisc  using "${homecd}dta/beta_gdp_growth.dta", gen(m_betas)
}

merge 1:1 fisc year using `inv_temp', gen(m_inv)

 



merge 1:1 fisc year using `mainbank_temp', gen(m_mban) keepusing(idbank)
drop if  m_mban==2
replace idbank = -999 if idbank==.




egen prov_sec4_yr = group( province ateco07_4D year)

xtset fisc year, yearly



if "${descriptives}" == "Yes" {

g  elasticity =  - v558
replace elasticity=. if elasticity < 0
replace elasticity=elasticity/10


g elasticity_96=elasticity
replace elasticity_96=. if year!=1996

g elasticity_07=elasticity
replace elasticity_07=. if year!=2007


bys sector: egen elasticity_median = median(elasticity)
bys sector: egen elasticity_mean = mean(elasticity)


g ratio_el =  elasticity_mean / ( elasticity_mean -1 )
replace ratio_el =1 if ratio_el <1

sum ratio_el

local corr_b  betaVA_cd_l betaVA_cd_k  betaY_cd_l betaY_cd_k betaY_cd_m

foreach b of local corr_b {

 
g quant_`b' = `b' * ratio_el
 
 g quant_`b'_lambda = `b'_lambda * ratio_el


}

}

************************************
**********   FOR ITBK  *************
************************************

if "${itbk}"=="Yes" {


g bla_2006=.
replace bla_2006=intbk if year==2006
bys fisc: egen intbk_2006=min(bla_2006)
drop bla_2006


g bla_2006=.
replace bla_2006=idbank if year==2006
bys fisc: egen idbank_2006=min(bla_2006)
drop bla_2006


g bla_2006=.
replace bla_2006=intbk_noCB if year==2006
bys fisc: egen intbk_noCB_2006=min(bla_2006)
drop bla_2006



g bla_2006=.
replace bla_2006=intbkuw if year==2006
bys fisc: egen intbkuw_2006=min(bla_2006)
drop bla_2006




g bla_2002=.
replace bla_2002=intbk if year==2002
bys fisc: egen intbk_2002=min(bla_2002)
drop bla_2002



g bla_2002=.
replace bla_2002=idbank if year==2002
bys fisc: egen idbank_2002=min(bla_2002)
drop bla_2002


winsor2 intbk_2002 intbk_2006 intbkuw_2006  intbk_noCB_2006, cuts(0 99) replace

sum intbk_2002 intbk_2006 intbkuw_2006  intbk_noCB_2006

}



************************************************************
************************************************************
**********  SAMPLE DEFINITION  ******************************
************************************************************
************************************************************

** Define Samples
xtset fisc year, yearly

g d_cred = D.cred 
winsor2 d_cred, cuts(1 99)



global conditions "if manufacture==1 & L.ACCORDATO_tot_eoy>0"

local a replace
local i 4  
quietly reghdfe  dp_`i'_w shifter ${conditions}, a(prov_sec_yr fisc)  
 
  g sample_manu_`i'=e(sample)


 


global conditions "if L.ACCORDATO_tot_eoy>0"

local a replace
local i 4  
quietly reghdfe  dp_`i'_w shifter ${conditions}, a(prov_sec_yr fisc)  
 
g sample_all_`i'=e(sample)




g open_vars=.


egen cluster_bank = group(year idbank)
xtset fisc year, yearly


forvalues i = 1/$N_prodvar {
cap g f2_dp`i'_w= F.dp_`i'_w + dp_`i'_w
}





g shifter_at2 = shifter*shifter
g shifter_at3 = shifter*shifter*shifter
 
reg  shifter L.( shifter shifter_at*   ) i.year 

predict innov_sh , res

drop shifter_at*  

 
capture  {

g shifter_at2 = shifter_dhs*shifter_dhs
g shifter_at3 = shifter_dhs*shifter_dhs*shifter_dhs
 
reg  shifter_dhs L.( shifter_dhs shifter_at*   ) i.year 

predict innov_sh_dhs , res
drop shifter_at*  

}


 **************************
*** year level dataset ***
**************************

if  "${year_ldta}" == "Yes" {

preserve
keep if sample_all_4==1
g rev_t = exp(ln_revenues)

g lab_prod_1 = rev_t / exp(n_dip)
g lab_prod_2 = va_op / exp(n_dip)

winsor2 lab_prod_1 lab_prod_2 , cuts(0 98) replace

collapse (sum) va_op va_op_def revenues_def ACCORDATO_tot_eoy wagebill_cerved_INPS  perpknet_CERVED1 rev_t (mean) ${prodvar_1}_w  ${prodvar_2}_w  ${prodvar_3}_w  ${prodvar_4}_w ///
dp_1_w  dp_2_w dp_3_w dp_4_w     lab_prod_1 lab_prod_2    /// 
(median) med_$prodvar_1 = $prodvar_1 med_$prodvar_2 = $prodvar_2  med_$prodvar_3 =$prodvar_3  med_$prodvar_4 =$prodvar_4 ///
med_lab_prod_1=lab_prod_1 med_lab_prod_2=lab_prod_2 ///
dp_1_med =dp_1  dp_2_med =dp_2 dp_3_med =dp_3 dp_4_med =dp_4 gdp_growth_pc=gdp_growth_pc , by(year)

cap erase $year_dta
save $year_dta

restore




preserve
keep if sample_manu_4==1
g rev_t = exp(ln_revenues)

g lab_prod_1 = rev_t / exp(n_dip)
g lab_prod_2 = va_op / exp(n_dip)

winsor2 lab_prod_1 lab_prod_2 , cuts(0 98) replace

collapse (sum) va_op va_op_def revenues_def ACCORDATO_tot_eoy wagebill_cerved_INPS  perpknet_CERVED1 rev_t (mean) ${prodvar_1}_w  ${prodvar_2}_w  ${prodvar_3}_w  ${prodvar_4}_w ///
dp_1_w  dp_2_w dp_3_w dp_4_w     lab_prod_1 lab_prod_2    /// 
(median) med_$prodvar_1 = $prodvar_1 med_$prodvar_2 = $prodvar_2  med_$prodvar_3 =$prodvar_3  med_$prodvar_4 =$prodvar_4 ///
med_lab_prod_1=lab_prod_1 med_lab_prod_2=lab_prod_2 ///
dp_1_med =dp_1  dp_2_med =dp_2 dp_3_med =dp_3 dp_4_med =dp_4 gdp_growth_pc=gdp_growth_pc , by(year)


cap erase $year_dta_manu
save $year_dta_manu

restore 
}

 
***********************************************
***********************************************
**********   TABLE 1 AND TABLE 2  ************* 
***********************************************
***********************************************

if "${descriptives}" == "Yes" {

** TABLE 1: right panel **
local i 4
file open des using "${homecd}tables/des_firms_manu_`i'.tex", write replace
file write des "Variable & Mean & Std. Dev. & Median & N \\ " _n
foreach x in va y l k matserv cred n_dip {
	g bla=exp(`x')
	quietly su bla if sample_manu_`i'==1, d
	local mean=round(r(mean),.1)
	local sd=round(r(sd),.1)
	local median= round(r(p50),.1)
	local n=r(N)
	file write des "$ `x' $ & `mean' & `sd' & `median' & `n' \\ " _n
	drop bla
}


file close des


** TABLE 1: left panel **

file open des using "${homecd}tables/des_firms_all_`i'.tex", write replace
file write des "Variable & Mean & Std. Dev. & Median & N \\ " _n
foreach x in va y l k matserv cred n_dip {
	g bla=exp(`x')
	quietly su bla if sample_all_`i'==1, d
	local mean=round(r(mean),.1)
	local sd=round(r(sd),.1)
	local median= round(r(p50),.1)
	local n=r(N)
	file write des "$ `x' $ & `mean' & `sd' & `median' & `n' \\ " _n
	drop bla
}

file close des

****

** TABLE 2: bottom panel **
** NOTE: betaVA_cd_l betaVA_cd_k betaVA_cd_l betaVA_cd_k are not included in the published version of the paper to streamelined the paper 
local i 4
file open des using "${homecd}tables/des_betaCD_manu_`i'.tex", write replace
file write des "Variable & Mean & Std. Dev. & Mean (Quantity) & Std. Dev. (Quantity) \\ " _n
foreach x in betaVA_cd_l betaVA_cd_k betaY_cd_l betaY_cd_k betaY_cd_m {
	 
	quietly su `x' if sample_manu_`i'==1, d
	local mean=round(r(mean),.01)
	local sd=round(r(sd),.01)
	
	quietly su quant_`x' if sample_manu_`i'==1, d
	local mean_quant=round(r(mean),.01)
	local sd_quant=round(r(sd),.01)


	file write des "$ `x' $ & `mean' & `sd' & `mean_quant' & `sd_quant' \\ " _n
}


file close des


** TABLE 2: upper panel **
file open des using "${homecd}tables/des_betaCD_all_`i'.tex", write replace
file write des "Variable & Mean & Std. Dev. & Mean (Quantity) & Std. Dev. (Quantity) \\ " _n
foreach x in betaVA_cd_l betaVA_cd_k betaY_cd_l betaY_cd_k betaY_cd_m {
	 
	quietly su `x' if sample_all_`i'==1, d
	local mean=round(r(mean),.01)
	local sd=round(r(sd),.01)
	
	quietly su quant_`x' if sample_all_`i'==1, d
	local mean_quant=round(r(mean),.01)
	local sd_quant=round(r(sd),.01)


	file write des "$ `x' $ & `mean' & `sd' & `mean_quant' & `sd_quant' \\ " _n
}

file close des



** TABLE 2: bottom panel **

local i 4
file open des using "${homecd}tables/des_betaCD_manu_`i'_lambda.tex", write replace
file write des "Variable & Mean & Std. Dev. & Mean (Quantity) & Std. Dev. (Quantity) \\ " _n
foreach x in betaVA_cd_l betaVA_cd_k betaY_cd_l betaY_cd_k betaY_cd_m {
	 
	quietly su `x'_lambda if sample_manu_`i'==1, d
	local mean=round(r(mean),.01)
	local sd=round(r(sd),.01)
	
	quietly su quant_`x'_lambda if sample_manu_`i'==1, d
	local mean_quant=round(r(mean),.01)
	local sd_quant=round(r(sd),.01)


	file write des "$ `x' $ & `mean' & `sd' & `mean_quant' & `sd_quant' \\ " _n
}


file close des


** TABLE 2: upper panel **

file open des using "${homecd}tables/des_betaCD_all_`i'_lambda.tex", write replace
file write des "Variable & Mean & Std. Dev. & Mean (Quantity) & Std. Dev. (Quantity) \\ " _n
foreach x in betaVA_cd_l betaVA_cd_k betaY_cd_l betaY_cd_k betaY_cd_m {
	 
	quietly su `x'_lambda if sample_all_`i'==1, d
	local mean=round(r(mean),.01)
	local sd=round(r(sd),.01)
	
	quietly su quant_`x'_lambda if sample_all_`i'==1, d
	local mean_quant=round(r(mean),.01)
	local sd_quant=round(r(sd),.01)


	file write des "$ `x' $ & `mean' & `sd' & `mean_quant' & `sd_quant' \\ " _n
}

file close des





label var shifter "Credit Supply Shock"
hist shifter if sample_all_4==1
graph export ${graphs}phi_hist.pdf , as(pdf) replace


label var dp_4_w "Growth Rate of Productivity"
hist dp_4_w if sample_all_4==1
graph export ${graphs}dp_4_hist.pdf , as(pdf) replace


cap {
label var dp_4_hw "Growth Rate of Productivity"
hist dp_4_w if sample_all_4==1
graph export ${graphs}dp_4_hist_hw.pdf , as(pdf) replace
}

label var prodva_cd_w "Hicks-neutral Productivity - Rev CD"
hist prodrev_tl_w if sample_all_4==1
graph export ${graphs}prodva_cd_hist.pdf , as(pdf) replace


label var prodva_cd_w "Hicks-neutral Productivity - Rev TL"
hist prodrev_cd_w if sample_all_4==1
graph export ${graphs}prodva_cd_hist.pdf , as(pdf) replace

 }

***********************************************
***********************************************
**********     TABLE 3    ****************
***********************************************
***********************************************

if "$main_specification"=="Yes" {
xtset fisc year, yearly

global conditions "if sample_manu_4==1"
global name_spec main_manu


* TABLE 3 columns 1 and 2, bottom panel are columns 1 and 3 of  ${tables}\main_manu

local a replace
forvalues i=1/$N_prodvar {
quietly reghdfe  dp_`i'_w shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex, `a'  ctitle("D.productivity")

local a append
}



global conditions "if sample_all_4==1"
global name_spec main_all

* TABLE 3 columns 1 and 2, upper panel are columns 1 and 3 of  ${tables}\main_all

local a replace
forvalues i=1/$N_prodvar {
quietly reghdfe  dp_`i'_w shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex, `a'  ctitle("D.productivity")

local a append
}

}


capture noisily {

if "$main_specification"=="Yes" {
	
	cap drop neg_dummy
	cap drop neg_shifter
	cap drop pos_dummy
	cap drop pos_shifter
	
	xtset fisc year, yearly

	
g neg_dummy = (innov_sh<0) if innov_sh!=. 
g neg_shifter = neg_dummy*innov_sh
g pos_dummy = (innov_sh>=0)*(innov_sh!=.)
g pos_shifter = pos_dummy*innov_sh


* TABLE 3 columns 3 and 4, bottom panel are columns 1 and 3 of  ${tables}\asymetry_manu_innov_F1


global conditions "if sample_manu_4==1"
global name_spec asymetry_manu_innov_F1


local a replace
forvalues i=1/$N_prodvar {
quietly reghdfe  f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex, `a'  ctitle("D.productivity")

 
local a append
}

* TABLE 3 columns 3 and 4, bottom panel are columns 1 and 3 of  ${tables}\assymetry_all_innov_F1


global conditions "if sample_all_4==1"
global name_spec assymetry_all_innov_F1

local a replace
forvalues i=1/$N_prodvar {
quietly reghdfe  f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex, `a'  ctitle("D.productivity")
 

local a append
}



}
}



***************************************** 
***************************************** 
**********     TABLE 4   ****************
***************************************** 
***************************************** 

preserve
	xtset fisc year , y
	keep if F.shifter!=. & shifter!=.
	xtile shifter, gen(shquart) nq(4)
	foreach x in prodrev_cd prodrev_tl dp_3_w dp_4_w va_op_def revenues_def book_value_k totass wagebill_cerved_INPS leverage {
		forval i=1/4 {
			su `x' if nq==`i',d
			scalar mT=r(mean)
			scalar vT=r(Var)

			su `x' if nq!=`i',d
			scalar mNT=r(mean)
			scalar vNT=r(Var)

			local stdiff=(mT-mNT)/sqrt((vT+vNT)/2)
			di "Standardized Difference of variable`x' for Quartile `i' of variable F.Shifter = `stdiff'"
		}
	}
restore
preserve
	xtset fisc year , y
	gen avgshifter=(shifter+L.shifter+L2.shifter)/3
	keep if year==2006 & intbk_2006!=.
	xtile intbk_2006, gen(shquart) nq(4)
	foreach x in prodrev_cd prodrev_tl dp_3_w dp_4_w va_op_def revenues_def book_value_k totass wagebill_cerved_INPS leverage shifter avgshifter {
		forval i=1/4 {
			su `x' if nq==`i',d
			scalar mT=r(mean)
			scalar vT=r(Var)

			su `x' if nq!=`i',d
			scalar mNT=r(mean)
			scalar vNT=r(Var)

			local stdiff=(mT-mNT)/sqrt((vT+vNT)/2)
			di "Standardized Difference of variable`x' for Quartile `i' of variable Interbank = `stdiff'"
		}
	}
restore


***************************************** 
***************************************** 
**********     TABLE 5   ****************
***************************************** 
***************************************** 

if "${itbk}" == "Yes" {


xtset fisc year, yearly



global name_spec all_intbk 
global conditions "   if year>2006 & year<2010 "

cap drop bla
reghdfe  dp_4_w intbk_2006  ${conditions}, a(prov_sec_yr)  vce(cluster fisc cluster_bank)
g bla = e(sample)


global conditions "if  bla==1"

* TABLE 5 columns 1 and 2, upper panel are columns 1 and 2 of  ${tables}\all_intbk

local a replace
local c 1
forvalues i=1/$N_prodvar {
quietly reghdfe  dp_`i'_w intbk_2006  ${conditions} , a(prov_sec_yr ) vce(cluster fisc cluster_bank)
outreg2 using "${tables}${name_spec}.tex", `a'  ctitle("D.productivity")
 *g ${name_spec}_c`c'=_b[intbk_2006]

local c `++c'
local a append

}



quietly reghdfe shifter intbk_2006   ${conditions} , a(prov_sec_yr)  vce(cluster fisc cluster_bank)
outreg2 using "${tables}credit.tex", replace ctitle("Credit Supply")
 g credit_itbk_c1=_b[intbk_2006]
 
 * TABLE 5 column  3, upper panel is column 2 of  ${tables}credit


quietly  reghdfe D.cred_w intbk_2006  ${conditions}, a(prov_sec_yr)  vce(cluster fisc cluster_bank)
outreg2 using "${tables}credit.tex", append ctitle("Credit Granted")
g credit_itbk_c2=_b[intbk_2006]


global name_spec manu_intbk
global conditions " if manufacture==1  & year>2006 & year<2010  "

cap drop bla

quietly reghdfe  dp_4_w intbk_2006  ${conditions}, a(prov_sec_yr)  vce(cluster fisc cluster_bank)
g bla = e(sample)

global conditions "if  bla==1"

* TABLE 5 columns 1 and 2, bottom panel are columns 1 and 2 of  ${tables}\manu_intbk


local a replace
local c 1
forvalues i=1/$N_prodvar {
quietly reghdfe  dp_`i'_w intbk_2006  ${conditions} , a(prov_sec_yr ) vce(cluster fisc cluster_bank)
outreg2 using "${tables}${name_spec}.tex", `a'  ctitle("D.productivity")
 
local c `++c'
local a append

}


 * TABLE 5 column  3, bottom panel is column 4 of  ${tables}credit

quietly reghdfe shifter intbk_2006   ${conditions} , a(prov_sec_yr)  vce(cluster fisc cluster_bank)
outreg2 using "${tables}credit.tex", append ctitle("Credit Supply")
 g credit_itbk_c3=_b[intbk_2006]

quietly  reghdfe D.cred_w intbk_2006  ${conditions}, a(prov_sec_yr)  vce(cluster fisc cluster_bank)
outreg2 using "${tables}credit.tex", append ctitle("Credit Granted")
 g credit_itbk_c4=_b[intbk_2006]




***** ***** ***** ***** ***** ***** 
***** Pretrend - ITBK ***** ****
***** ***** ***** ***** ***** ***** 
xtset fisc year, yearly


global name_spec all_intbk_pl_large
global conditions "   if year>2003 & year<2007 "

cap drop bla
reghdfe  dp_4_w intbk_2006  ${conditions}, a(prov_sec_yr)  
g bla = e(sample)
global conditions "if  bla==1"


local a replace
local c 3
forvalues i=1/$N_prodvar {
quietly reghdfe  dp_`i'_w intbk_2006  ${conditions} , a(prov_sec_yr )  vce(cluster fisc cluster_bank)
outreg2 using "${tables}${name_spec}.tex", `a'  ctitle("D.productivity")
 local c `++c'
local a append

}



global name_spec manu_intbk_pl_large 
global conditions " if manufacture==1 & year>2003 & year<2007  "

cap drop bla

reghdfe  dp_4_w intbk_2006  ${conditions}, a(prov_sec_yr)   vce(cluster fisc cluster_bank)
g bla = e(sample)
global conditions "if  bla==1"



local a replace
local c 3
forvalues i=1/$N_prodvar {
quietly reghdfe  dp_`i'_w intbk_2006  ${conditions} , a(prov_sec_yr )  vce(cluster fisc cluster_bank)
outreg2 using "${tables}${name_spec}.tex", `a'  ctitle("D.productivity")
 
local c `++c'
local a append

}

**********



xtset fisc year, yearly

 
}



 
 
***********************************************
***********************************************
********** TABLE A1  ****************
***********************************************
***********************************************

if "${inout_specification}" == "Yes"  {



global conditions "if manufacture==1 & sample_manu_4==1"


local in_out $raw
local i 1
local a replace
global name_spec inout_NB

foreach var of local in_out {

quietly reghdfe d_`var'_w shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex,  `a' ctitle("D.`var'")

 g ${name_spec}_`var'=_b[shifter]


quietly reghdfe d_`var'_w shifter_imctr ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_contr.tex,  `a' ctitle("D.`var'")

 g ${name_spec}_contr_`var'=_b[shifter]


quietly reghdfe d_`var'_w shifter_dhs ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_dhs.tex,  `a' ctitle("D.`var'")

 g ${name_spec}_dhs_`var'=_b[shifter]








local a append
}



global conditions "if sample_all_4==1"


local in_out $raw
local i 1
local a replace
global name_spec inout_all

foreach var of local in_out {

quietly reghdfe d_`var'_w shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_`var'=_b[shifter]


quietly reghdfe d_`var'_w shifter_imctr ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_contr.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_contr_`var'=_b[shifter_imctr]


quietly reghdfe d_`var'_w shifter_dhs ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_dhs.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_dhs_`var'=_b[shifter_dhs]


local a append
}






global conditions "if   sample_manu_4==1"


local in_out $raw
local i 1
local a replace
global name_spec inout_manu_4dgs

foreach var of local in_out {

  
quietly reghdfe d_`var'_w shifter ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_`var'=_b[shifter]


quietly reghdfe d_`var'_w shifter_imctr ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_contr.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_contr_`var'=_b[shifter_imctr]


quietly reghdfe d_`var'_w shifter_dhs ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_dhs.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_dhs_`var'=_b[shifter_dhs]



local a append
}



global conditions "if sample_all_4==1"


local in_out $raw
local i 1
local a replace
global name_spec inout_all_4dgs

foreach var of local in_out {


quietly reghdfe d_`var'_w shifter ${conditions}, a(prov_sec4_yr fisc)   vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_`var'=_b[shifter]


quietly reghdfe d_`var'_w shifter_imctr ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_contr.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_contr_`var'=_b[shifter_imctr]


quietly reghdfe d_`var'_w shifter_dhs ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_dhs.tex,  `a' ctitle("D.`var'")

 *g ${name_spec}_dhs_`var'=_b[shifter_dhs] 

local a append
}

}



***********************************************
***********************************************
********** TABLE A2 ****************
***********************************************
***********************************************



if "${robustness}" == "Yes" {
	
	 * TABLE A2 is sample_all_4

		preserve 
	
cap drop neg_dummy
	cap drop neg_shifter
	cap drop pos_dummy
	cap drop pos_shifter
	
g neg_dummy = (innov_sh<0) if innov_sh!=. 
g neg_shifter = neg_dummy*innov_sh
g pos_dummy = 1 - neg_dummy if innov_sh!=. 
g pos_shifter = pos_dummy*innov_sh

cap drop nyiinsample
bys fisc: gen nyiinsample = _N 


xtset fisc year, yearly
cap g  fd2p_3cs_ps_w = F.dp_3_cs_ps_w + dp_3_cs_ps_w
cap g  fd2p_3_EEXIT_w =  F.dp_3_EEXIT_w + dp_3_EEXIT_w
cap g fd2p_3_NE4dgs_w = F.dp_3_NE4dgs_w + dp_3_NE4dgs_w

global conditions "if   sample_manu_4==1"
global name_spec robustness_manu_asymmetry_innov_F1
local i 3 
local c 1

quietly reghdfe f2_dp`i'_w  pos_shifter neg_shifter ${conditions}  , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, replace  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 

 local c `++c'

 
quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter L2.(${controls}) ${conditions}  , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'


quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions} & max_checkshacceoy <0.01, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'

 
 
quietly reghdfe  f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(year sector)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'

quietly reghdfe  f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(year prov_num sector fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'

 
 
 rename neg_shifter temp_a 
 rename pos_shifter temp_b 
 
 g neg_shifter = shifter_imctr*(shifter_imctr<0)
g pos_shifter =  shifter_imctr*(shifter_imctr>=0)
  
quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
  local c `++c'
  drop pos_shifter neg_shifter
  rename  temp_a  neg_shifter
 rename  temp_b  pos_shifter

 
 cap g neg_shifter_split = shifter_split*neg_dummy
 cap g pos_shifter_split = shifter_split*pos_dummy
 
 ivreghdfe  f2_dp`i'_w (pos_shifter neg_shifter = pos_shifter_split neg_shifter_split)  ${conditions}, a(prov_sec_yr fisc)  cluster(fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
  local c `++c'
 

quietly reghdfe fd2p_3_NE4dgs_w pos_shifter neg_shifter ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'

 
quietly reghdfe fd2p_3_EEXIT_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'


  quietly reghdfe fd2p_3cs_ps_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'
 
 
 capture noisily {
 	
	cap drop pos_shifter_dhs
	cap drop neg_shifter_dhs
 g pos_shifter_dhs = shifter_dhs*pos_dummy 
 g neg_shifter_dhs = shifter_dhs*neg_dummy 
 
 quietly reghdfe f2_dp`i'_w pos_shifter_dhs neg_shifter_dhs ${conditions}  , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")

	
	
 

 
 quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}  &  nyiinsample>4 , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
}


 quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}  &  nyiinsample>4 & (year<2007 | year >2009) , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 

global conditions "if   sample_all_4==1"

global name_spec robustness_all_asymmetry_innov_F1
 
local c 1


quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}  , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, replace  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 

 local c `++c'

 
quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter L2.(${controls}) ${conditions}  , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'


quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions} & max_checkshacceoy <0.01, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'

 
 
quietly reghdfe  f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(year sector)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
 *g ${name_spec}_`i'_c`c'=_b[shifter]
 *g ${name_spec}_`i'_neg_c`c'=_b[neg_shifter]
 local c `++c'

quietly reghdfe  f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(year prov_num sector fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
  local c `++c'

 
 
 rename neg_shifter temp_a 
 rename pos_shifter temp_b 
 
 g neg_shifter = shifter_imctr*(shifter_imctr<0)
g pos_shifter =  shifter_imctr*(shifter_imctr>=0)
  
quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
   local c `++c'
  drop pos_shifter neg_shifter
  rename  temp_a  neg_shifter
 rename  temp_b  pos_shifter

 
 cap g neg_shifter_split = shifter_split*neg_dummy
 cap g pos_shifter_split = shifter_split*pos_dummy
 
 ivreghdfe  f2_dp`i'_w (pos_shifter neg_shifter = pos_shifter_split neg_shifter_split)  ${conditions}, a(prov_sec_yr fisc)  cluster(fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
   local c `++c'
 

quietly reghdfe fd2p_3_NE4dgs_w pos_shifter neg_shifter ${conditions}, a(prov_sec4_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
  local c `++c'

 
quietly reghdfe fd2p_3_EEXIT_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
  local c `++c'


  quietly reghdfe fd2p_3cs_ps_w pos_shifter neg_shifter ${conditions}, a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
  local c `++c'

 xtset fisc year 
 
 
 capture noisily {
 	
	
	
	
	cap drop pos_shifter_dhs
	cap drop neg_shifter_dhs
 g pos_shifter_dhs = innov_sh_dhs*pos_dummy 
 g neg_shifter_dhs = innov_sh_dhs*neg_dummy 
 
 quietly reghdfe f2_dp`i'_w pos_shifter_dhs neg_shifter_dhs ${conditions}  , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")

	
	
 

  quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}  & nyiinsample>4 , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")
}

  quietly reghdfe f2_dp`i'_w pos_shifter neg_shifter ${conditions}  &  nyiinsample>4 & (year<2007 | year >2009) , a(prov_sec_yr fisc)  vce(cluster fisc cluster_bank)
outreg2 using ${tables}${name_spec}_`i'.tex, append  ctitle("Productivity")

 restore 
 

}

 
***************************************** *************
***************************************** *************
**********     TABLE 6 and  TABLE A3  ****************
***************************************** *************
***************************************** *************




if "${productivity_enhancing}" == "Yes"  {



g logpc_INVIND=log(t1) 

winsor2 logpc_INVIND  , cuts(1 99) by(year) replace
g logpc_overk= logpc_INVIND  - k

g rd_dummy=(F.v451p>0) 
replace rd_dummy=. if F.v451p==.




g expt_INVIND=(ser6>0)
replace expt_INVIND=. if ser6==.
replace expt_INVIND=(F.ser5>0) if ser6==. & F.ser5!=.
tab expt_INVIND




g inv_con=(ostin2==3) + (ostin2==4)

replace inv_con=. if ostin2==.


*TABLE 6 column 1 is column 1 of  ${tables}prodenhance
quietly reghdfe   logpc_overk shifter, a(prov_sec_yr fisc)  vce(cluster fisc)
outreg2 using ${tables}prodenhance.tex,  replace ctitle("PC over K")


preserve 


u ${homecd}dta/pat_mark, clear




drop if mprior==2
drop if mapp==2
drop if mpub==2
drop if mmark==2
replace nupat_application =0 if nupat_application==. & year>1999 & year<2013

replace numark =0 if numark==. & year>1998 & year<2014

g anypat=nupat_application >0  & nupat_application<.
replace anypat =. if nupat_application ==.
g anymark=numark>0 & numark<.
replace anymark=. if numark==.
replace anypat=. if year<=1999 | year>=2013
replace anymark=. if year<=1998 | year>=2014


 xtset fisc year, yearly


global conditions "if L.ACCORDATO_tot_eoy>0"

local i 4  
quietly reghdfe  dp_`i'_w shifter ${conditions}, a(prov_sec_yr fisc)  
 
  g sample_all_`i'=e(sample)

	
g patent_growth_1 =  2*(nupat_application - L2.nupat_application) / (nupat_application + L2.nupat_application)

*TABLE A3 column 1 and 2  are column 2 and 3 of  ${tables}prodenhance

    quietly	reghdfe  nupat_application   L.shifter if sample_all_4==1 & year>1999 & year< 2013, a(prov_sec_yr fisc)  vce(cluster fisc )  
	outreg2 using ${tables}prodenhance.tex, append ctitle("No. of Patents")	


	quietly	reghdfe  patent_growth_1   L.shifter if sample_all_4==1 & year>1999 & year< 2013, a(prov_sec_yr fisc)  vce(cluster fisc )  
	outreg2 using ${tables}prodenhance.tex, append ctitle("Patent Growth")	



g bla_2006=.
replace bla_2006=intbk if year==2006
bys fisc: egen intbk_2006=min(bla_2006)
drop bla_2006



winsor2  intbk_2006 , cuts(0 98) replace



g pat_pre = nupat_application 
replace pat_pre = . if year > 2006 | year < 2002
g pat_post = nupat_application 
replace pat_post = . if year < 2007 | year > 2009


bys fisc: egen pat_pre_tot_2 = total(pat_pre)
bys fisc: egen pat_post_tot_2 = total(pat_post)

g patent_growth_2 = 2*(pat_post_tot_2- pat_pre_tot_2)/(pat_post_tot_2+ pat_pre_tot_2)



drop   pat_pre pat_post 

g pat_pre = nupat_application 
replace pat_pre = . if year > 2006 | year < 2001
g pat_post = nupat_application 
replace pat_post = . if year < 2007 | year > 2010


bys fisc: egen pat_pre_tot_3 = total(pat_pre)
bys fisc: egen pat_post_tot_3 = total(pat_post)

g patent_growth_3 = 2*(pat_post_tot_3- pat_pre_tot_3)/(pat_post_tot_3 + pat_pre_tot_3)




drop   pat_pre pat_post 

g pat_pre = nupat_application 
replace pat_pre = . if year > 2006 | year < 2001
g pat_post = nupat_application 
replace pat_post = . if year < 2007 | year > 2009


bys fisc: egen pat_pre_tot_4 = total(pat_pre)
bys fisc: egen pat_post_tot_4 = total(pat_post)

g patent_growth_4 = 2*(pat_post_tot_4- pat_pre_tot_4)/(pat_post_tot_4 + pat_pre_tot_4)



*TABLE A3 column 3  is column 1  of  ${tables}patent_itbk

    quietly reghdfe  patent_growth_2 intbk_2006 if year == 2006 , a(prov_num sector) vce(cluster prov_num sector)
	outreg2 using ${tables}patent_itbk.tex, replace 	ctitle("Patent Growth")	

	quietly reghdfe  patent_growth_3 intbk_2006 if year == 2006 , a(prov_num sector) vce(cluster prov_num sector)
	outreg2 using ${tables}patent_itbk.tex, append 	ctitle("Patent Growth")	
	outreg2 using ${tables}prodenhance.tex, append 	ctitle("Patent Growth")	

	sum patent_growth_3 intbk_2006 if e(sample)
	
	quietly reghdfe  patent_growth_4 intbk_2006 if year == 2006 , a(prov_num sector) vce(cluster prov_num sector)
	outreg2 using ${tables}patent_itbk.tex, append 	ctitle("Patent Growth")	
	
	
restore
	

*TABLE 6 column 2, 3 and 4  are column 5, 6, and 7 of  ${tables}prodenhance

reghdfe rd_dummy shifter , a(prov_sec_yr fisc) vce(cluster fisc)
outreg2 using ${tables}prodenhance.tex, append ctitle("R&D")

 reghdfe expt_INVIND shifter , a(prov_sec_yr fisc) vce(cluster fisc)
outreg2 using ${tables}prodenhance.tex, append ctitle("Export")	


reghdfe inv_con shifter, a(prov_sec_yr) vce(robust)
outreg2 using ${tables}prodenhance.tex, append 	ctitle("Fin Const")

	


	reghdfe rd_dummy shifter , a(sector prov_num year fisc) vce(cluster fisc)

	
 
preserve 




restore 
}





	 

*save "${homecd}dta/iteration_0.dta", replace




